@@ -87,7 +87,6 @@ import abc
 import inspect
 import os
 import re
-import io
 
 from sphinx.util import logging
 from sphinx.ext.autosummary import Autosummary
@@ -125,6 +124,7 @@ class Automodsumm(Autosummary):
     option_spec['allowed-package-names'] = _str_list_converter
     option_spec['inherited-members'] = flag
     option_spec['no-inherited-members'] = flag
+    option_spec['noindex'] = flag
 
     def run(self):
         env = self.state.document.settings.env
@@ -312,7 +312,7 @@ def automodsumm_to_autosummary_lines(fn, app):
 
     fullfn = os.path.join(app.builder.env.srcdir, fn)
 
-    with io.open(fullfn, encoding='utf8') as fr:
+    with open(fullfn, encoding='utf8') as fr:
         # Note: we use __name__ here instead of just writing the module name in
         #       case this extension is bundled into another package
         from . import automodapi
@@ -458,7 +458,7 @@ def generate_automodsumm_docs(lines, srcfn, app=None, suffix='.rst',
     new_files = []
 
     # write
-    for name, path, template_name, inherited_mem in sorted(items):
+    for name, path, template_name, inherited_mem, noindex in sorted(items):
 
         if path is None:
             # The corresponding autosummary:: directive did not have
@@ -488,7 +488,7 @@ def generate_automodsumm_docs(lines, srcfn, app=None, suffix='.rst',
 
         new_files.append(fn)
 
-        f = open(fn, 'w')
+        f = open(fn, 'w', encoding='utf8')
 
         try:
 
@@ -602,6 +602,7 @@ def generate_automodsumm_docs(lines, srcfn, app=None, suffix='.rst',
             else:
                 mod_name, obj_name = '.'.join(parts[:-1]), parts[-1]
 
+            ns['noindex'] = noindex
             ns['fullname'] = name
             ns['module'] = mod_name
             ns['objname'] = obj_name
